@@ -164,7 +164,7 @@ int main(int argc, char **argv) /* qhold */
   if (errflg || optind >= argc)
     {
     static char usage[] = "usage: qhold [-h hold_list] job_identifier...\n";
-    fprintf(stderr, usage);
+    fprintf(stderr,"%s", usage);
     exit(2);
     }
 
