@@ -1,45 +1,45 @@
 /*
 *         OpenPBS (Portable Batch System) v2.3 Software License
-* 
+*
 * Copyright (c) 1999-2000 Veridian Information Solutions, Inc.
 * All rights reserved.
-* 
+*
 * ---------------------------------------------------------------------------
 * For a license to use or redistribute the OpenPBS software under conditions
 * other than those described below, or to purchase support for this software,
 * please contact Veridian Systems, PBS Products Department ("Licensor") at:
-* 
+*
 *    www.OpenPBS.org  +1 650 967-4675                  sales@OpenPBS.org
 *                        877 902-4PBS (US toll-free)
 * ---------------------------------------------------------------------------
-* 
+*
 * This license covers use of the OpenPBS v2.3 software (the "Software") at
 * your site or location, and, for certain users, redistribution of the
 * Software to other sites and locations.  Use and redistribution of
 * OpenPBS v2.3 in source and binary forms, with or without modification,
 * are permitted provided that all of the following conditions are met.
 * After December 31, 2001, only conditions 3-6 must be met:
-* 
+*
 * 1. Commercial and/or non-commercial use of the Software is permitted
 *    provided a current software registration is on file at www.OpenPBS.org.
 *    If use of this software contributes to a publication, product, or
 *    service, proper attribution must be given; see www.OpenPBS.org/credit.html
-* 
+*
 * 2. Redistribution in any form is only permitted for non-commercial,
 *    non-profit purposes.  There can be no charge for the Software or any
 *    software incorporating the Software.  Further, there can be no
 *    expectation of revenue generated as a consequence of redistributing
 *    the Software.
-* 
+*
 * 3. Any Redistribution of source code must retain the above copyright notice
 *    and the acknowledgment contained in paragraph 6, this list of conditions
 *    and the disclaimer contained in paragraph 7.
-* 
+*
 * 4. Any Redistribution in binary form must reproduce the above copyright
 *    notice and the acknowledgment contained in paragraph 6, this list of
 *    conditions and the disclaimer contained in paragraph 7 in the
 *    documentation and/or other materials provided with the distribution.
-* 
+*
 * 5. Redistributions in any form must be accompanied by information on how to
 *    obtain complete source code for the OpenPBS software and any
 *    modifications and/or additions to the OpenPBS software.  The source code
@@ -47,23 +47,23 @@
 *    than the cost of distribution plus a nominal fee, and all modifications
 *    and additions to the Software must be freely redistributable by any party
 *    (including Licensor) without restriction.
-* 
+*
 * 6. All advertising materials mentioning features or use of the Software must
 *    display the following acknowledgment:
-* 
+*
 *     "This product includes software developed by NASA Ames Research Center,
-*     Lawrence Livermore National Laboratory, and Veridian Information 
+*     Lawrence Livermore National Laboratory, and Veridian Information
 *     Solutions, Inc.
 *     Visit www.OpenPBS.org for OpenPBS software support,
 *     products, and information."
-* 
+*
 * 7. DISCLAIMER OF WARRANTY
-* 
+*
 * THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND. ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, AND NON-INFRINGEMENT
 * ARE EXPRESSLY DISCLAIMED.
-* 
+*
 * IN NO EVENT SHALL VERIDIAN CORPORATION, ITS AFFILIATED COMPANIES, OR THE
 * U.S. GOVERNMENT OR ANY OF ITS AGENCIES BE LIABLE FOR ANY DIRECT OR INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
@@ -72,21 +72,21 @@
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-* 
+*
 * This license will be governed by the laws of the Commonwealth of Virginia,
 * without reference to its choice of law rules.
 */
 /*
  *  parse_jobid
  *
- * takes a job_id string as input, parses it to separate the 
- * 'current_server[:port]' part, and returns this in the return 
+ * takes a job_id string as input, parses it to separate the
+ * 'current_server[:port]' part, and returns this in the return
  * argument 'server'; if things go OK, the function value is
  * set to 0, if errors, it is set to 1.   The 'current_server[:port]'
  * part of 'job_id' is removed, if it was present.
  *
  * Full legal syntax is:
- *  seq_number[.parent_server[:port]][@current_server[:port]]  
+ *  seq_number[.parent_server[:port]][@current_server[:port]]
  */
 
 #include <pbs_config.h>   /* the master config generated by configure */
@@ -98,79 +98,107 @@
 #define MAXSERVERNAME PBS_MAXSERVERNAME+PBS_MAXPORTNUM+2
 #define ISNAMECHAR(x) ( (isgraph(x)) && ((x) != '#') && ( (x) != '@') )
 
-static char seq_number[PBS_MAXSEQNUM+PBS_MAXJOBARRAYLEN+1]; 
+static char seq_number[PBS_MAXSEQNUM+PBS_MAXJOBARRAYLEN+1];
 static int s_pos;
-static char parent_server[MAXSERVERNAME]; 
+static char parent_server[MAXSERVERNAME];
 static int p_pos;
-static char current_server[MAXSERVERNAME]; 
+static char current_server[MAXSERVERNAME];
 static int c_pos;
 
-int parse_jobid(job_id, arg_seq_number, arg_parent_server, arg_current_server)
-char *job_id;
-char **arg_seq_number;
-char **arg_parent_server;
-char **arg_current_server;
-{
-    int i;
-    char *c;
+int
+parse_jobid(char *job_id, char **arg_seq_number, char **arg_parent_server, char **arg_current_server)
+  {
+  int i;
+  char *c;
 
-    /* initialize static data for this parsing call */
-    for ( i=0; i<PBS_MAXSEQNUM+PBS_MAXJOBARRAYLEN+1; i++ ) seq_number[i]='\0';
-    s_pos = 0;
-    for ( i=0; i<MAXSERVERNAME; i++ ) parent_server[i]='\0';
-    p_pos = 0;
-    for ( i=0; i<MAXSERVERNAME; i++ ) current_server[i]='\0';
-    c_pos = 0;
+  /* initialize static data for this parsing call */
 
-    /* Begin the parse */
-    c = job_id;
-    while ( isspace(*c) ) c++;
+  for (i = 0; i < PBS_MAXSEQNUM + PBS_MAXJOBARRAYLEN + 1; i++) seq_number[i] = '\0';
 
-    /* Looking for a seq_number */
-    while ( *c != '\0' ) {
-        if ( isdigit(*c) || *c =='-') {
-	    if ( s_pos >= PBS_MAXSEQNUM+PBS_MAXJOBARRAYLEN ) return 3;
-            seq_number[s_pos++]=*c;
-        } else
-            break;
-        c++;
+  s_pos = 0;
+
+  for (i = 0; i < MAXSERVERNAME; i++) parent_server[i] = '\0';
+
+  p_pos = 0;
+
+  for (i = 0; i < MAXSERVERNAME; i++) current_server[i] = '\0';
+
+  c_pos = 0;
+
+  /* Begin the parse */
+  c = job_id;
+
+  while (isspace(*c)) c++;
+
+  /* Looking for a seq_number */
+  while (*c != '\0')
+    {
+    if (isdigit(*c) || *c == '-')
+      {
+      if (s_pos >= PBS_MAXSEQNUM + PBS_MAXJOBARRAYLEN) return 3;
+
+      seq_number[s_pos++] = *c;
+      }
+    else
+      break;
+
+    c++;
     }
-    if ( s_pos == 0 ) return 1;
 
-    /* Looking for a parent_server */
-    if ( *c == '.' ) {
-        c++;
-        while ( *c != '\0' ) {
-            if ( ISNAMECHAR(*c) ) {
-	        if ( p_pos >= MAXSERVERNAME ) return 3;
-                parent_server[p_pos++]=*c;
-            } else
-                break;
-            c++;
+  if (s_pos == 0) return 1;
+
+  /* Looking for a parent_server */
+  if (*c == '.')
+    {
+    c++;
+
+    while (*c != '\0')
+      {
+      if (ISNAMECHAR(*c))
+        {
+        if (p_pos >= MAXSERVERNAME) return 3;
+
+        parent_server[p_pos++] = *c;
         }
-        if ( p_pos == 0 ) return 1;
+      else
+        break;
+
+      c++;
+      }
+
+    if (p_pos == 0) return 1;
     }
 
-    /* Looking for a current_server */
-    if ( *c == '@' ) {
-        c++;
-        while ( *c != '\0' ) {
-            if ( ISNAMECHAR(*c) ) {
-	        if ( c_pos >= MAXSERVERNAME ) return 3;
-                current_server[c_pos++]=*c;
-            } else
-                break;
-            c++;
+  /* Looking for a current_server */
+  if (*c == '@')
+    {
+    c++;
+
+    while (*c != '\0')
+      {
+      if (ISNAMECHAR(*c))
+        {
+        if (c_pos >= MAXSERVERNAME) return 3;
+
+        current_server[c_pos++] = *c;
         }
-        if ( c_pos == 0 ) return 1;
+      else
+        break;
+
+      c++;
+      }
+
+    if (c_pos == 0) return 1;
     }
 
-    if ( *c != '\0' ) return 2;
+  if (*c != '\0') return 2;
 
-    /* set char * pointers to static data, to arguments */
-    if ( arg_seq_number != NULL ) *arg_seq_number = seq_number;
-    if ( arg_parent_server != NULL ) *arg_parent_server = parent_server;
-    if ( arg_current_server != NULL ) *arg_current_server = current_server;
+  /* set char * pointers to static data, to arguments */
+  if (arg_seq_number != NULL) *arg_seq_number = seq_number;
 
-    return 0;
-}
+  if (arg_parent_server != NULL) *arg_parent_server = parent_server;
+
+  if (arg_current_server != NULL) *arg_current_server = current_server;
+
+  return 0;
+  }
