@@ -116,7 +116,7 @@
 #include "server_limits.h"
 #include "attribute.h"
 #include "resource.h"
-#include "job.h"
+#include "pbs_job.h"
 #include "log.h"
 #include "mom_mach.h"
 #include "resmon.h"
@@ -145,7 +145,7 @@
 **  quota  quota information (sizes in KB)
 */
 
-static char ident[] = "@(#) sgi/$RCSfile$ $Revision: 2628 $";
+static char ident[] = "@(#) sgi/$RCSfile$ $Revision: 3151 $";
 
 #ifndef TRUE
 #define FALSE 0
@@ -186,7 +186,6 @@ time_t  wait_time = 10;
 extern char extra_parm[];
 extern char no_parm[];
 
-extern struct pbs_err_to_txt pbs_err_to_txt[];
 extern time_t   time_now;
 extern time_t   last_scan;
 
@@ -203,7 +202,9 @@ extern double cputfactor;
 extern double wallfactor;
 extern  long    system_ncpus;
 extern  int     ignwalltime;
+extern  int     igncput;
 extern  int     ignvmem;
+extern  int     ignmem;
 
 /*
 ** local functions and data
@@ -357,9 +358,8 @@ rlim64_t  *ret;
  * decoded value of time in seconds in the unsigned long integer.
  */
 
-static int getlong(pres, ret)
-resource  *pres;
-unsigned long *ret;
+static int
+getlong(resource *pres, unsigned long *ret)
   {
 
   if (pres->rs_value.at_type != ATR_TYPE_LONG)
@@ -381,9 +381,8 @@ unsigned long *ret;
  * decoded value of time in seconds in the unsigned long integer.
  */
 
-static int gettime(pres, ret)
-resource  *pres;
-unsigned long *ret;
+static int
+gettime(resource *pres, unsigned long *ret)
   {
 
   if (pres->rs_value.at_type != ATR_TYPE_LONG)
@@ -408,11 +407,8 @@ unsigned long *ret;
 **      Scan a list of tasks and return true if one of them matches
 **      the process (sid or pid) represented by *psp.
 */
-static
-int
-injob(phead, psp)
-tlist_head  *phead;
-prpsinfo_t *psp;
+static int
+injob(tlist_head *phead, prpsinfo_t *psp)
   {
   task  *ptask;
   pid_t  key;
@@ -439,8 +435,8 @@ prpsinfo_t *psp;
  * Accepts a job pointer.  Returns the sum of all cpu time
  * consumed for all tasks executed by the job, in seconds.
  */
-static unsigned long cput_sum(pjob)
-job *pjob;
+static unsigned long
+cput_sum(job *pjob)
   {
   char   *id = "cput_ses";
   int   i;
@@ -480,9 +476,8 @@ job *pjob;
 /*
  * Return TRUE if any process in the job is over limit for cputime usage.
  */
-static int overcpu_proc(phead, limit)
-tlist_head  *phead;
-unsigned long limit;
+static int
+overcpu_proc(tlist_head *phead, unsigned long limit)
   {
   ulong  cputime;
   int  i;
@@ -690,28 +685,14 @@ extern char *msg_momsetlim;
 int
 error(char *string, int value)
   {
-  int  i = 0;
   char  *message;
 
   assert(string != NULL);
   assert(*string != '\0');
-  assert(value > PBSE_);   /* minimum PBS error number */
-  assert(value <= PBSE_NOSYNCMSTR); /* maximum PBS error number */
-  assert(pbs_err_to_txt[i].err_no != 0);
 
-  do
-    {
-    if (pbs_err_to_txt[i].err_no == value)
-      break;
-    }
-  while (pbs_err_to_txt[++i].err_no != 0);
-
-  assert(pbs_err_to_txt[i].err_txt != NULL);
-
-  message = *pbs_err_to_txt[i].err_txt;
+  message = pbse_to_txt(value);
 
   assert(message != NULL);
-
   assert(*message != '\0');
 
   (void)fprintf(stderr, msg_momsetlim, string, message);
@@ -742,9 +723,11 @@ error(char *string, int value)
  * existing limits.  Cannot alter those set by setrlimit (kernel)
  * because we are the wrong process.
  */
-int mom_set_limits(pjob, set_mode)
-job   *pjob;
-int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
+int
+mom_set_limits(
+  job *pjob,
+  int set_mode /* SET_LIMIT_SET or SET_LIMIT_ALTER */
+)
   {
   char  *id = "mom_set_limits";
   char  *pname;
@@ -797,25 +780,31 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
       }
     else if (strcmp(pname, "cput") == 0)   /* check */
       {
-      /* cpu time - check, if less than pcput use it */
-      retval = gettime(pres, &value);
+      if (igncput == FALSE)
+        {
+        /* cpu time - check, if less than pcput use it */
+        retval = gettime(pres, &value);
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
+        }
       }
     else if (strcmp(pname, "pcput") == 0)
       {
-      /* process cpu time - set */
-      retval = gettime(pres, &value);
+      if (igncput == FALSE)
+        {
+        /* process cpu time - set */
+        retval = gettime(pres, &value);
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
 
-      res64lim.rlim_cur = res64lim.rlim_max =
-                            (unsigned long)((double)value / cputfactor);
+        res64lim.rlim_cur = res64lim.rlim_max =
+          (unsigned long)((double)value / cputfactor);
 
-      if (setrlimit64(RLIMIT_CPU, &res64lim) < 0)
-        return (error("RLIMIT_CPU", PBSE_SYSTEM));
+        if (setrlimit64(RLIMIT_CPU, &res64lim) < 0)
+          return (error("RLIMIT_CPU", PBSE_SYSTEM));
+        }
       }
     else if (strcmp(pname, "file") == 0)   /* set */
       {
@@ -834,40 +823,49 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
       }
     else if (strcmp(pname, "vmem") == 0)   /* check */
       {
-      retval = getsize(pres, &sizeval);
+      if (ignvmem == FALSE)
+        {
+        retval = getsize(pres, &sizeval);
+ 
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
-
-      if ((mem_limit == 0) || (sizeval < mem_limit))
-        mem_limit = sizeval;
+        if ((mem_limit == 0) || (sizeval < mem_limit))
+          mem_limit = sizeval;
+        }
       }
     else if (strcmp(pname, "pvmem") == 0)   /* set */
       {
-      retval = getsize(pres, &sizeval);
+      if (ignvmem == FALSE)
+        {
+        retval = getsize(pres, &sizeval);
+ 
+        if (retval != PBSE_NONE)
+          return (error(pname, retval));
 
-      if (retval != PBSE_NONE)
-        return (error(pname, retval));
-
-      if ((mem_limit == 0) || (sizeval < mem_limit))
-        mem_limit = sizeval;
+        if ((mem_limit == 0) || (sizeval < mem_limit))
+          mem_limit = sizeval;
+        }
       }
     else if (strcmp(pname, "mem") == 0)    /* ignore */
       {
       }
     else if (strcmp(pname, "pmem") == 0)   /* set */
       {
-      if (set_mode == SET_LIMIT_SET)
+      if (ignmem == FALSE)
         {
-        retval = getsize(pres, &sizeval);
+        if (set_mode == SET_LIMIT_SET)
+          {
+          retval = getsize(pres, &sizeval);
 
-        if (retval != PBSE_NONE)
-          return (error(pname, retval));
+          if (retval != PBSE_NONE)
+            return (error(pname, retval));
 
-        res64lim.rlim_cur = res64lim.rlim_max = sizeval;
+          res64lim.rlim_cur = res64lim.rlim_max = sizeval;
 
-        if (setrlimit64(RLIMIT_RSS, &res64lim) < 0)
-          return (error("RLIMIT_RSS", PBSE_SYSTEM));
+          if (setrlimit64(RLIMIT_RSS, &res64lim) < 0)
+            return (error("RLIMIT_RSS", PBSE_SYSTEM));
+          }
         }
       }
     else if (strcmp(pname, "walltime") == 0)   /* Check */
@@ -935,8 +933,8 @@ int    set_mode; /* SET_LIMIT_SET or SET_LIMIT_ALTER */
  * polling is done using the mom_over_limit machine-dependent function.
  */
 
-int mom_do_poll(pjob)
-job   *pjob;
+int
+mom_do_poll(job *pjob)
   {
   char  *id = "mom_do_poll";
   char  *pname;
@@ -1119,8 +1117,8 @@ mom_get_sample(void)
  * Otherwise, return FALSE.
  */
 
-int mom_over_limit(pjob)
-job   *pjob;
+int
+mom_over_limit(job *pjob)
   {
   char  *pname;
   int  retval;
@@ -1180,7 +1178,7 @@ job   *pjob;
 #endif /* SGI_ZOMBIE_WRONG */
         }
       }
-    else if (strcmp(pname, "cput") == 0)
+    else if ((igncput == FALSE) && (strcmp(pname, "cput") == 0))
       {
       retval = getlong(pres, &value);
 
@@ -1195,7 +1193,7 @@ job   *pjob;
         return (TRUE);
         }
       }
-    else if (strcmp(pname, "pcput") == 0)
+    else if ((igncput == (FALSE)) && (strcmp(pname, "pcput") == 0))
       {
       retval = getlong(pres, &value);
 
@@ -1238,7 +1236,7 @@ job   *pjob;
         return (TRUE);
         }
       }
-    else if (strcmp(pname, "walltime") == 0)
+    else if (ignwalltime == 0 && strcmp(pname, "walltime") == 0)
       {
       if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_HERE) == 0)
         continue;
@@ -1255,9 +1253,7 @@ job   *pjob;
         sprintf(log_buffer,
                 "walltime %ld exceeded limit %lu",
                 num, value);
-
-        if (ignwalltime == 0)
-          return (TRUE);
+        return (TRUE);
         }
       }
     }
@@ -1272,8 +1268,8 @@ job   *pjob;
  * each resource that can be reported for this machine.  Fill in the
  * correct values.  Return an error code.
  */
-int mom_set_use(pjob)
-job   *pjob;
+int
+mom_set_use(job *pjob)
   {
   resource  *pres;
   attribute  *at;
@@ -1388,10 +1384,8 @@ job   *pjob;
  * Kill a task session.
  * Call with the task pointer and a signal number.
  */
-int kill_task(ptask, sig, pg)
-task *ptask;
-int  sig;
-int         pg;
+int
+kill_task(task *ptask, int sig, int pg)
   {
   char  *id = "kill_task";
   int  ct = 0;
@@ -1482,17 +1476,16 @@ mom_close_poll(void)
   }
 
 /*
- * mom_does_chkpnt - return 1 if mom supports checkpoint
- *       0 if not
+ * mom_does_checkpoint
  */
 
 int
-mom_does_chkpnt(void)
+mom_does_checkpoint(void)
   {
 #if MOM_CHECKPOINT == 1
-  return (1);
+  return (CST_MACH_DEP);
 #else /* MOM_CHECKPOINT */
-  return (0);
+  return (CST_NONE);
 #endif /* MOM_CHECKPOINT */
   }
 
@@ -1502,10 +1495,8 @@ mom_does_chkpnt(void)
  * If abort is true, kill it too.
  */
 
-int mach_checkpoint(ptask, file, abort)
-task *ptask;
-char *file;
-int  abort;
+int
+mach_checkpoint(task *ptask, char *file, int abort)
   {
 #if MOM_CHECKPOINT == 1
   /* ckpt_setup(0, 0);  Does nothing so why have it */
@@ -1530,9 +1521,8 @@ int  abort;
  * Return -1 on error or sid if okay.
  */
 
-long mach_restart(ptask, file)
-task *ptask;
-char *file;
+long
+mach_restart(task *ptask, char *file)
   {
 #if MOM_CHECKPOINT == 1
   ckpt_id_t rc;
