@@ -3640,8 +3640,6 @@ char *size(
 
 
 
-
-
 /*
  * For a recovering (-p) mom, look through existing tasks in existing
  * jobs for things that have exited that are not owned by us through a
@@ -3656,6 +3654,9 @@ void scan_non_child_tasks(void)
 
   job *job;
   extern tlist_head svr_alljobs;
+#ifdef USESAVEDRESOURCES
+  static int first_time = TRUE;
+#endif    /* USESAVEDRESOURCES */
 
   DIR *pdir;  /* use local pdir to prevent race conditions associated w/global pdir (VPAC) */
 
@@ -3735,12 +3736,34 @@ void scan_non_child_tasks(void)
 
         task_save(task);
 
+#ifdef USESAVEDRESOURCES
+        if (first_time)
+          {
+          job->ji_flags |= MOM_JOB_RECOVERY;
+          if (LOGLEVEL >= 7)
+            {
+            sprintf(buf, "marking job as MOM_JOB_RECOVERY for task %d",
+                task->ti_qs.ti_task);
+
+            LOG_EVENT(
+              PBSEVENT_DEBUG,
+              PBS_EVENTCLASS_JOB,
+              job->ji_qs.ji_jobid,
+              buf);
+            }
+          }
+#endif    /* USESAVEDRESOURCES */
+
         exiting_tasks = 1;
         }
       }
     }    /* END for (job = GET_NEXT(svr_alljobs)) */
 
   closedir(pdir);
+  
+#ifdef USESAVEDRESOURCES
+  first_time = FALSE;
+#endif    /* USESAVEDRESOURCES */
 
   return;
   }  /* END scan_non_child_tasks() */
