@@ -92,9 +92,9 @@
 
 extern int job_set_wait A_((attribute *, void *, int));
 extern int action_resc A_((attribute *, void *, int));
-extern int ck_chkpnt A_((attribute *, void *, int));
+extern int ck_checkpoint A_((attribute *, void *, int));
 extern int depend_on_que A_((attribute *, void *, int));
-extern int comp_chkpnt A_((attribute *, attribute *));
+extern int comp_checkpoint A_((attribute *, attribute *));
 
 #define ATR_DFLAG_SSET  (ATR_DFLAG_SvWR | ATR_DFLAG_SvRD)
 
@@ -112,8 +112,8 @@ extern int comp_chkpnt A_((attribute *, attribute *));
  * parent object type
  */
 
-/* sync w/enum job_atr in src/include/job.h */
-/* sync w/ TJobAttr[] in src/resmom/request.c */
+/* sync w/enum job_atr in src/include/pbs_job.h */
+/* sync w/ TJobAttr[] in src/resmom/requests.c */
 
 attribute_def job_attr_def[] =
   {
@@ -202,7 +202,7 @@ attribute_def job_attr_def[] =
     ATR_TYPE_STR,
     PARENT_TYPE_JOB
   },
-  /* JOB_ATR_chkpnt */
+  /* JOB_ATR_checkpoint */
   { ATTR_c,   /* "Checkpoint" */
     decode_str,
     encode_str,
@@ -210,19 +210,23 @@ attribute_def job_attr_def[] =
 #ifdef PBS_MOM
     comp_str,
 #else /* PBS_MOM - server side */
-    comp_chkpnt,
+    comp_checkpoint,
 #endif /* PBS_MOM */
     free_str,
 #ifdef PBS_MOM
     NULL_FUNC,
 #else /* PBS_MOM - server side */
-    ck_chkpnt,
+#if 0
+    ck_checkpoint,
+#else
+    0,
+#endif
 #endif /* PBS_MOM */
     READ_WRITE | ATR_DFLAG_MOM | ATR_DFLAG_ALTRUN,
     ATR_TYPE_STR,
     PARENT_TYPE_JOB
   },
-  /* JOB_ATR_ctime */
+  /* JOB_ATR_ctime */    /* create time, set when the job is queued */
   { ATTR_ctime,  /* "ctime" */
     decode_l,
     encode_l,
@@ -331,18 +335,6 @@ attribute_def job_attr_def[] =
     ATR_TYPE_LONG,
     PARENT_TYPE_JOB
   },
-  /* JOB_ATR_jobtype */
-  { ATTR_jobtype,   /* "Job_Type" */
-    decode_str,
-    encode_str,
-    set_str,
-    comp_str,
-    free_str,
-    NULL_FUNC,
-    READ_WRITE | ATR_DFLAG_SELEQ | ATR_DFLAG_MOM,
-    ATR_TYPE_STR,
-    PARENT_TYPE_JOB
-  },
   /* JOB_ATR_join */
   { ATTR_j,   /* "Join_Path" */
     decode_str,
@@ -547,7 +539,7 @@ attribute_def job_attr_def[] =
     comp_arst,
     free_arst,
     NULL_FUNC,
-    READ_WRITE | ATR_DFLAG_SELEQ | ATR_DFLAG_MOM | ATR_DFLAG_PRIVR,
+    READ_WRITE | ATR_DFLAG_SELEQ | ATR_DFLAG_MOM | ATR_DFLAG_PRIVR | ATR_DFLAG_ALTRUN,
     ATR_TYPE_ARST,
     PARENT_TYPE_JOB
   },
@@ -780,7 +772,7 @@ attribute_def job_attr_def[] =
     comp_l,
     free_null,
     NULL_FUNC,
-    READ_ONLY | ATR_DFLAG_SSET,
+    READ_ONLY | ATR_DFLAG_SSET | ATR_DFLAG_MOM,
     ATR_TYPE_LONG,
     PARENT_TYPE_JOB
   },
@@ -798,8 +790,8 @@ attribute_def job_attr_def[] =
     PARENT_TYPE_JOB
   },
 
-  /* JOB_ATR_chkptdir */
-  { ATTR_chkptdir,  /* "checkpoint_dir" */
+  /* JOB_ATR_checkpoint_dir */
+  { ATTR_checkpoint_dir,  /* "checkpoint_dir" */
     decode_str,
     encode_str,
     set_str,
@@ -811,8 +803,8 @@ attribute_def job_attr_def[] =
     PARENT_TYPE_JOB
   },
 
-  /* JOB_ATR_chkptname */
-  { ATTR_chkptname,  /* "checkpoint_name" */
+  /* JOB_ATR_checkpoint_name */
+  { ATTR_checkpoint_name,  /* "checkpoint_name" */
     decode_str,
     encode_str,
     set_str,
@@ -824,6 +816,58 @@ attribute_def job_attr_def[] =
     PARENT_TYPE_JOB
   },
 
+  /* JOB_ATR_checkpoint_time */
+  { ATTR_checkpoint_time,  /* "checkpoint_time" */
+    decode_l,
+    encode_l,
+    set_l,
+    comp_l,
+    free_null,
+    NULL_FUNC,
+    NO_USER_SET | ATR_DFLAG_SvWR | ATR_DFLAG_ALTRUN,
+    ATR_TYPE_LONG,
+    PARENT_TYPE_JOB
+  },
+
+  /* JOB_ATR_checkpoint_restart_status */
+  { ATTR_checkpoint_restart_status,  /* "checkpoint_restart_status" */
+    decode_str,
+    encode_str,
+    set_str,
+    comp_str,
+    free_str,
+    NULL_FUNC,
+    READ_WRITE | ATR_DFLAG_SvWR | ATR_DFLAG_ALTRUN,
+    ATR_TYPE_STR,
+    PARENT_TYPE_JOB
+  },
+
+  /* JOB_ATR_restart_name */
+  { ATTR_restart_name,  /* "restart_name" */
+    decode_str,
+    encode_str,
+    set_str,
+    comp_str,
+    free_str,
+    NULL_FUNC,
+    NO_USER_SET | ATR_DFLAG_SvWR | ATR_DFLAG_ALTRUN | ATR_DFLAG_MOM,
+    ATR_TYPE_STR,
+    PARENT_TYPE_JOB
+  },
+
+  /* JOB_ATR_f (fault_tolerant)*/
+  { ATTR_f,
+    decode_b,
+    encode_b,
+    set_b,
+    comp_b,
+    free_null,
+    NULL_FUNC,
+    READ_WRITE | ATR_DFLAG_ALTRUN | ATR_DFLAG_SELEQ | ATR_DFLAG_MOM,
+    ATR_TYPE_LONG,
+    PARENT_TYPE_JOB
+  },
+
   /* JOB_ATR_comp_time */
   { ATTR_comp_time, /* completion time */
     decode_l,
@@ -850,6 +894,47 @@ attribute_def job_attr_def[] =
   	PARENT_TYPE_JOB
   },
 
+  /* JOB_ATR_jobtype */
+  { ATTR_jobtype,   /* "Job_Type" */
+    decode_str,
+    encode_str,
+    set_str,
+    comp_str,
+    free_str,
+    NULL_FUNC,
+    READ_WRITE | ATR_DFLAG_SELEQ | ATR_DFLAG_MOM,
+    ATR_TYPE_STR,
+    PARENT_TYPE_JOB
+  },
+
+  /* JOB_ATR_inter_cmd */
+  { ATTR_intcmd,   /* "Interactive_Cmd" */
+    decode_str,
+    encode_str,
+    set_str,
+    comp_str,
+    free_str,
+    NULL_FUNC,
+    READ_WRITE | ATR_DFLAG_MOM,
+    ATR_TYPE_STR,
+    PARENT_TYPE_JOB
+  },
+
+#ifdef ENABLE_CSA
+  /* JOB_ATR_pagg_id */
+  { ATTR_pagg,  /* "pagg_id" */
+    decode_ll,
+    encode_ll,
+    set_ll,
+    comp_ll,
+    free_null,
+    NULL_FUNC,
+    READ_ONLY | ATR_DFLAG_SvWR,
+    ATR_TYPE_LL,
+    PARENT_TYPE_JOB
+  },
+#endif /* ENABLE_CSA */
+
   /* Site defined attributes if any, see site_job_attr_*.h  */
 #include "site_job_attr_def.h"
 
